@@ -1,11 +1,6 @@
-#' shiny.hdlm
-#'
-#' @title Executes a 'shiny' app for HDLM.
-#' @description Method for executing a 'shiny' app to provide comprehensive analysis with HDLM. The app includes PIP, split points, individualized & subgroup-specific effects.
-#'
-#' @param fit an object of class 'hdlm'
-#'
-#' @returns A 'shiny' app interface 
+#' @method shiny hdlm
+#' @rdname shiny
+#' 
 #' @export
 shiny.hdlm <- function(fit)
 {
@@ -42,7 +37,7 @@ shiny.hdlm <- function(fit)
           geom_line(aes(x = as.numeric(time - 1), y = est)) +
           facet_wrap(~group)
     if (groups == 2) {
-      p <- p + facet_grid(grp1 ~ grp2)
+      p <- p + facet_grid(grp2 ~ grp1)
     } else {
       p <- p + facet_wrap(~group)
     }
@@ -318,10 +313,9 @@ shiny.hdlm <- function(fit)
           if (fit$modIsNum[sub_mod1]) { # Single numerical modifier
             # print("num")
 
-            # Find the middle splitpoint
-            spl       <- splitpoints(fit, var = sub_mod1, round = 2)
-            spl$cumu  <- cumsum(spl$proportion)
-            mid_loc   <- spl$location[length(which(spl$cumu < 0.5)) + 1]
+            # Find the mode of proportion
+            spl <- splitpoints(fit, var = sub_mod1, round = 3)
+            mid_loc <- spl$location[which(spl$proportion == max(spl$proportion))]
             
             mod_num   <- c(paste0(sub_mod1," < ", mid_loc), paste0(mid_loc, " =< ", sub_mod1))
             list_num  <- vector("list", length = length(mod_num))
@@ -479,16 +473,14 @@ shiny.hdlm <- function(fit)
         } else {
           if (fit$modIsNum[sub_mod1]) { # numerical modifier
             if (fit$modIsNum[sub_mod2]){      # num x num              
-              # Find the middle splitpoint
+              # Find the mode of proportion
               # modifier 1
-              spl       <- splitpoints(fit, var = sub_mod1, round = 2)
-              spl$cumu  <- cumsum(spl$proportion)
-              mid_loc1  <- spl$location[length(which(spl$cumu < 0.5)) + 1]
+              spl <- splitpoints(fit, var = sub_mod1, round = 3)
+              mid_loc1 <- spl$location[which(spl$proportion == max(spl$proportion))]
               
-              # modifier 1
-              spl <- splitpoints(fit, var = sub_mod2, round = 2)
-              spl$cumu <- cumsum(spl$proportion)
-              mid_loc2 <- spl$location[length(which(spl$cumu < 0.5)) + 1]
+              # modifier 2
+              spl <- splitpoints(fit, var = sub_mod2, round = 3)
+              mid_loc2 <- spl$location[which(spl$proportion == max(spl$proportion))]
               
               mod1_num <- c(paste0(sub_mod1, " < ", mid_loc1), paste0(mid_loc1, " =< ", sub_mod1))
               mod2_num <- c(paste0(sub_mod2, " < ", mid_loc2), paste0(mid_loc2, " =< ", sub_mod2))
@@ -575,9 +567,8 @@ shiny.hdlm <- function(fit)
             } else { # num x cat
               # Find the middle splitpoint
               # modifier 1
-              spl       <- splitpoints(fit, var = sub_mod1, round = 2)
-              spl$cumu  <- cumsum(spl$proportion)
-              mid_loc1  <- spl$location[length(which(spl$cumu < 0.5)) + 1]
+              spl <- splitpoints(fit, var = sub_mod1, round = 3)
+              mid_loc1 <- spl$location[which(spl$proportion == max(spl$proportion))]
               
               mod1_num    <- c(paste0(sub_mod1, " < ", mid_loc1), paste0(mid_loc1, " =< ", sub_mod1))
               mod2_cat    <- pull(unique(fit$data[, sub_mod2]))
@@ -667,9 +658,8 @@ shiny.hdlm <- function(fit)
               mod1_cat <- pull(unique(fit$data[, sub_mod1]))
               
               # modifier 2
-              spl       <- splitpoints(fit, var = sub_mod2, round = 2)
-              spl$cumu  <- cumsum(spl$proportion)
-              mid_loc2  <- spl$location[length(which(spl$cumu < 0.5)) + 1]
+              spl <- splitpoints(fit, var = sub_mod2, round = 3)
+              mid_loc2 <- spl$location[which(spl$proportion == max(spl$proportion))]
               mod2_num  <- c(paste0(sub_mod2, " < ", mid_loc2), paste0(mid_loc2, " =< ", sub_mod2))
               
               comb        <- expand.grid(mod1_cat, mod2_num) %>% mutate(comb = paste0(Var1, " & ", Var2))
@@ -851,8 +841,8 @@ shiny.hdlm <- function(fit)
           if (sub_mod2 == "No selection"){
             # 1 modifier
             incProgress(1/2, detail = paste(" weighted subgroup effect: ", sub_mod1))
-            grpDLM <- estDLM(fit, fit$data[complete.cases(fit$data),],
-                            createGrpIdx(fit, fit$data[complete.cases(fit$data),], sub_mod1), verbose = FALSE)
+            grpDLM <- estDLM(fit, fit$data,
+                            createGrpIdx(fit, fit$data, sub_mod1), verbose = FALSE)
             incProgress(1/2, detail = "")
             
             plotDLM(grpDLM) + 
@@ -861,8 +851,8 @@ shiny.hdlm <- function(fit)
           } else {
             # 2 modifiers
             incProgress(1/2, detail = paste(" weighted subgroup effect: ", sub_mod1, " & ", sub_mod2))
-            grpDLM <- estDLM(fit, fit$data[complete.cases(fit$data),],
-                            create2GrpIdx(fit, fit$data[complete.cases(fit$data),], sub_mod1, sub_mod2), verbose = FALSE)
+            grpDLM <- estDLM(fit, fit$data,
+                            create2GrpIdx(fit, fit$data, sub_mod1, sub_mod2), verbose = FALSE)
             incProgress(1/2, detail = "")
             
             plotDLM(grpDLM, groups = 2) + 
@@ -877,4 +867,4 @@ shiny.hdlm <- function(fit)
   }
 
   shinyApp(ui = ui, server = server)
-}
+}
\ No newline at end of file
